summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorluz.paz <luzpaz@users.noreply.github.com>2018-06-03 17:14:36 -0400
committerluz paz <luzpaz@users.noreply.github.com>2018-06-12 17:23:14 -0400
commitf9dd3ebe76d0e89ce08d614292920cafdbee146d (patch)
treeca4d4e600c1bc725ce7e2f8ba0a64b90b95885ed
parent638270f7ec4cd58dd0bd72c6e3c33785f63f638c (diff)
Source typos
Found via `codespell` and `grep`
-rw-r--r--lib/fidlib/fidrf_jit.h2
-rw-r--r--plugins/soundsourcem4a/soundsourcem4a.cpp2
-rwxr-xr-xplugins/soundsourcemediafoundation/soundsourcemediafoundation.cpp2
-rw-r--r--src/analyzer/analyzerwaveform.h2
-rw-r--r--src/control/controlbehavior.cpp12
-rw-r--r--src/encoder/encodermp3.cpp4
-rw-r--r--src/encoder/encodermp3.h2
-rw-r--r--src/encoder/encodervorbis.cpp4
-rw-r--r--src/encoder/encodervorbis.h2
-rw-r--r--src/engine/cachingreader.cpp2
-rw-r--r--src/track/globaltrackcache.cpp18
-rw-r--r--src/track/globaltrackcache.h2
-rw-r--r--src/waveform/renderers/glslwaveformrenderersignal.cpp4
-rw-r--r--vamp-plugins/dsp/tempotracking/TempoTrack.h2
14 files changed, 30 insertions, 30 deletions
diff --git a/lib/fidlib/fidrf_jit.h b/lib/fidlib/fidrf_jit.h
index 8d3ba81a2f..cebb404626 100644
--- a/lib/fidlib/fidrf_jit.h
+++ b/lib/fidlib/fidrf_jit.h
@@ -241,7 +241,7 @@ static unsigned long int do_hash(unsigned char *, unsigned long int, unsigned lo
//
static char *r_buf; // Buffer address
-static char *r_end; // Curent end of buffer
+static char *r_end; // Current end of buffer
static char *r_cp; // Current write-position
static char *r_lab; // Current loop-back label, or 0
static int r_loop; // Loop count
diff --git a/plugins/soundsourcem4a/soundsourcem4a.cpp b/plugins/soundsourcem4a/soundsourcem4a.cpp
index 192cc7f132..4654a3bb7c 100644
--- a/plugins/soundsourcem4a/soundsourcem4a.cpp
+++ b/plugins/soundsourcem4a/soundsourcem4a.cpp
@@ -42,7 +42,7 @@ const MP4SampleId kSampleBlockIdMin = 1;
// https://developer.apple.com/library/ios/technotes/tn2258/_index.html
// "It must also be assumed that without an explicit value, the playback
// system will trim 2112 samples from the AAC decoder output when starting
-// playback from any point in the bistream."
+// playback from any point in the bitstream."
const SINT kNumberOfPrefetchFrames = 2112;
// The TrackId is a 1-based index of the tracks in an MP4 file
diff --git a/plugins/soundsourcemediafoundation/soundsourcemediafoundation.cpp b/plugins/soundsourcemediafoundation/soundsourcemediafoundation.cpp
index c1a751b948..90d7c91da4 100755
--- a/plugins/soundsourcemediafoundation/soundsourcemediafoundation.cpp
+++ b/plugins/soundsourcemediafoundation/soundsourcemediafoundation.cpp
@@ -25,7 +25,7 @@ constexpr SINT kLeftoverSize = 4096; // in CSAMPLE's, this seems to be the size
// https://developer.apple.com/library/ios/technotes/tn2258/_index.html
// "It must also be assumed that without an explicit value, the playback
// system will trim 2112 samples from the AAC decoder output when starting
-// playback from any point in the bistream."
+// playback from any point in the bitstream."
constexpr SINT kNumberOfPrefetchFrames = 2112;
// Only read the first audio stream
diff --git a/src/analyzer/analyzerwaveform.h b/src/analyzer/analyzerwaveform.h
index 085194707d..fe1834e56e 100644
--- a/src/analyzer/analyzerwaveform.h
+++ b/src/analyzer/analyzerwaveform.h
@@ -147,7 +147,7 @@ class AnalyzerWaveform : public Analyzer {
void finalize(TrackPointer tio) override;
private:
- void storeCurentStridePower();
+ void storeCurrentStridePower();
void resetCurrentStride();
void createFilters(int sampleRate);
diff --git a/src/control/controlbehavior.cpp b/src/control/controlbehavior.cpp
index 89f294d7ef..720fa7399e 100644
--- a/src/control/controlbehavior.cpp
+++ b/src/control/controlbehavior.cpp
@@ -125,15 +125,15 @@ double ControlLogPotmeterBehavior::valueToParameter(double dValue) {
} else if (dValue < m_dMinValue) {
dValue = m_dMinValue;
}
- double linPrameter = (dValue - m_dMinValue) / m_dValueRange;
- double dbParamter = ratio2db(linPrameter + m_minOffset * (1 - linPrameter));
- return 1 - (dbParamter / m_minDB);
+ double linParameter = (dValue - m_dMinValue) / m_dValueRange;
+ double dbParameter = ratio2db(linParameter + m_minOffset * (1 - linParameter));
+ return 1 - (dbParameter / m_minDB);
}
double ControlLogPotmeterBehavior::parameterToValue(double dParam) {
- double dbParamter = (1 - dParam) * m_minDB;
- double linPrameter = (db2ratio(dbParamter) - m_minOffset) / (1 - m_minOffset);
- return m_dMinValue + (linPrameter * m_dValueRange);
+ double dbParameter = (1 - dParam) * m_minDB;
+ double linParameter = (db2ratio(dbParameter) - m_minOffset) / (1 - m_minOffset);
+ return m_dMinValue + (linParameter * m_dValueRange);
}
ControlLogInvPotmeterBehavior::ControlLogInvPotmeterBehavior(
diff --git a/src/encoder/encodermp3.cpp b/src/encoder/encodermp3.cpp
index 034dce3b1a..cb69db74bf 100644
--- a/src/encoder/encodermp3.cpp
+++ b/src/encoder/encodermp3.cpp
@@ -28,7 +28,7 @@
// of values for the slider.
// The threshold of bitrate (CBR/ABR) at which the encoder
// with switch to mono encoding
-const int EncoderMp3::MONO_BITRATE_TRESHOLD = 100;
+const int EncoderMp3::MONO_BITRATE_THRESHOLD = 100;
// The threshold of quality (VBR) at which the encoder
// with switch to mono encoding. Values from 0 to 6 encode at 44Khz
const int EncoderMp3::MONO_VBR_THRESHOLD = 8;
@@ -269,7 +269,7 @@ void EncoderMp3::setEncoderSettings(const EncoderSettings& settings)
m_encoding_mode = (modeoption==0) ? vbr_off : (modeoption==1) ? vbr_abr : vbr_default;
if (m_encoding_mode == vbr_off) {
- if (m_bitrate > MONO_BITRATE_TRESHOLD ) {
+ if (m_bitrate > MONO_BITRATE_THRESHOLD ) {
m_stereo_mode = JOINT_STEREO;
} else {
m_stereo_mode = MONO;
diff --git a/src/encoder/encodermp3.h b/src/encoder/encodermp3.h
index 9d53b46d23..4faa60312b 100644
--- a/src/encoder/encodermp3.h
+++ b/src/encoder/encodermp3.h
@@ -19,7 +19,7 @@ class EncoderCallback;
class EncoderMp3 : public Encoder {
public:
- static const int MONO_BITRATE_TRESHOLD;
+ static const int MONO_BITRATE_THRESHOLD;
static const int MONO_VBR_THRESHOLD;
static const int MONO_VBR_OFFSET;
diff --git a/src/encoder/encodervorbis.cpp b/src/encoder/encodervorbis.cpp
index fa7d053bca..0296579948 100644
--- a/src/encoder/encodervorbis.cpp
+++ b/src/encoder/encodervorbis.cpp
@@ -31,7 +31,7 @@ http://svn.xiph.org/trunk/vorbis/examples/encoder_example.c
// of values for the slider.
// The threshold of bitrate at which the encoder
// with switch to mono encoding
-const int EncoderVorbis::MONO_BITRATE_TRESHOLD = 70;
+const int EncoderVorbis::MONO_BITRATE_THRESHOLD = 70;
EncoderVorbis::EncoderVorbis(EncoderCallback* pCallback)
@@ -65,7 +65,7 @@ void EncoderVorbis::setEncoderSettings(const EncoderSettings& settings)
case EncoderSettings::ChannelMode::STEREO: m_channels = 2; break;
case EncoderSettings::ChannelMode::AUTOMATIC: // fallthrough
default:
- if (m_bitrate > MONO_BITRATE_TRESHOLD ) {
+ if (m_bitrate > MONO_BITRATE_THRESHOLD ) {
m_channels = 2;
}
else {
diff --git a/src/encoder/encodervorbis.h b/src/encoder/encodervorbis.h
index 43cc5f3179..5ab13db09d 100644
--- a/src/encoder/encodervorbis.h
+++ b/src/encoder/encodervorbis.h
@@ -21,7 +21,7 @@ class EncoderCallback;
class EncoderVorbis : public Encoder {
public:
- static const int MONO_BITRATE_TRESHOLD;
+ static const int MONO_BITRATE_THRESHOLD;
EncoderVorbis(EncoderCallback* pCallback=nullptr);
virtual ~EncoderVorbis();
diff --git a/src/engine/cachingreader.cpp b/src/engine/cachingreader.cpp
index 2440b3a8f8..e39ff72c3d 100644
--- a/src/engine/cachingreader.cpp
+++ b/src/engine/cachingreader.cpp
@@ -17,7 +17,7 @@ mixxx::Logger kLogger("CachingReader");
// This is the default hint frameCount that is adopted in case of Hint::kFrameCountForward and
// Hint::kFrameCountBackward count is provided. It matches 23 ms @ 44.1 kHz
-// TODO() Do we suffer chache misses if we use an audio buffer of above 23 ms?
+// TODO() Do we suffer cache misses if we use an audio buffer of above 23 ms?
const SINT kDefaultHintFrames = 1024;
// currently CachingReaderWorker::kCachingReaderChunkLength is 65536 (0x10000);
diff --git a/src/track/globaltrackcache.h b/src/track/globaltrackcache.h
index fabb664fae..bc4caa3032 100644
--- a/src/track/globaltrackcache.h
+++ b/src/track/globaltrackcache.h
@@ -186,7 +186,7 @@ public:
static void evictAndSaveCachedTrack(GlobalTrackCacheEntryPointer cacheEntryPtr);
private slots:
- void evictAndSave(GlobalTrackCacheEntryPointer chacheEntryPtr);
+ void evictAndSave(GlobalTrackCacheEntryPointer cacheEntryPtr);
private:
friend class GlobalTrackCacheLocker;
diff --git a/src/waveform/renderers/glslwaveformrenderersignal.cpp b/src/waveform/renderers/glslwaveformrenderersignal.cpp
index 7f2ce1d003..78c8aeb22f 100644
--- a/src/waveform/renderers/glslwaveformrenderersignal.cpp
+++ b/src/waveform/renderers/glslwaveformrenderersignal.cpp
@@ -120,9 +120,9 @@ bool GLSLWaveformRendererSignal::loadTexture() {
// Waveform ensures that getTextureSize is a multiple of
// getTextureStride so there is no rounding here.
int textureWidth = waveform->getTextureStride();
- int textureHeigth = waveform->getTextureSize() / waveform->getTextureStride();
+ int textureHeight = waveform->getTextureSize() / waveform->getTextureStride();
- glTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA, textureWidth, textureHeigth, 0,
+ glTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA, textureWidth, textureHeight, 0,
GL_RGBA, GL_UNSIGNED_BYTE, data);
int error = glGetError();
if (error)
diff --git a/vamp-plugins/dsp/tempotracking/TempoTrack.h b/vamp-plugins/dsp/tempotracking/TempoTrack.h
index 0c315717ba..c973eba6ec 100644
--- a/vamp-plugins/dsp/tempotracking/TempoTrack.h
+++ b/vamp-plugins/dsp/tempotracking/TempoTrack.h
@@ -92,7 +92,7 @@ private:
double* m_ACoeffs;
double* m_BCoeffs;
- // Objetcs/operators declaration
+ // Objects/operators declaration
Framer m_DFFramer;
DFProcess* m_DFConditioning;
Correlation m_correlator;
diff --git a/src/track/globaltrackcache.cpp b/src/track/globaltrackcache.cpp
index b68553f496..8522be3696 100644
--- a/src/track/globaltrackcache.cpp
+++ b/src/track/globaltrackcache.cpp
@@ -581,8 +581,8 @@ TrackRef GlobalTrackCache::initTrackId(
}
void GlobalTrackCache::evictAndSave(
- GlobalTrackCacheEntryPointer chacheEntryPtr) {
- DEBUG_ASSERT(chacheEntryPtr);
+ GlobalTrackCacheEntryPointer cacheEntryPtr) {
+ DEBUG_ASSERT(cacheEntryPtr);
// We need to besure this is always called from the main thread
// because we can only access the DB from it and we must not loose the
@@ -592,33 +592,33 @@ void GlobalTrackCache::evictAndSave(
GlobalTrackCacheLocker cacheLocker;
- if (!chacheEntryPtr->getSavingWeakPtr().expired()) {
+ if (!cacheEntryPtr->getSavingWeakPtr().expired()) {
// We have handed out (revived) this track again after our reference count
// drops to zero and before acquire the lock at the beginning of this function
if (debugLogEnabled()) {
kLogger.debug()
<< "Skip to evict and save a revived or reallocated track"
- << chacheEntryPtr->getPlainPtr();
+ << cacheEntryPtr->getPlainPtr();
}
return;
}
- if (!evict(chacheEntryPtr->getPlainPtr())) {
+ if (!evict(cacheEntryPtr->getPlainPtr())) {
// A scond deleter has already evict the track from cache after our
// reference count drops to zero and before acquire the lock at the
// beginning of this function
if (debugLogEnabled()) {
kLogger.debug()
<< "Skip to save an already evicted track"
- << chacheEntryPtr->getPlainPtr();
+ << cacheEntryPtr->getPlainPtr();
}
return;
}
- DEBUG_ASSERT(isEvicted(chacheEntryPtr->getPlainPtr()));
- m_pSaver->saveCachedTrack(chacheEntryPtr->getPlainPtr());
+ DEBUG_ASSERT(isEvicted(cacheEntryPtr->getPlainPtr()));
+ m_pSaver->saveCachedTrack(cacheEntryPtr->getPlainPtr());
- // here the chacheEntryPtr goes out of scope, the cache is deleted
+ // here the cacheEntryPtr goes out of scope, the cache is deleted
// including the owned track
}